# HDInsight

> see https://aka.ms/autorest

This is the AutoRest configuration file for HDInsight.



---
## Getting Started
To build the SDK for HDInsight, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the HDInsight API.

``` yaml
title: HDInsightManagementClient
description: HDInsight Management Client
openapi-type: arm
azure-arm: true
tag: package-2018-06-preview
```

## Suppression
 ``` yaml
 directive:
   - suppress: DefinitionsPropertiesNamesCamelCase
     reason: This would require a breaking change, and the capabilities API was removed in version 2018-06-01-preview.
     from: Microsoft.HDInsight/preview/2015-03-01-1/preview/locations.json
     where:
       - $.definitions.CapabilitiesResult.properties.vmSize_filters
       - $.definitions.RegionalQuotaCapability.properties.cores_available
       - $.definitions.RegionalQuotaCapability.properties.cores_used
       - $.definitions.RegionalQuotaCapability.properties.region_name
       - $.definitions.VmSizeCompatibilityFilter.properties.ClusterVersions
       - $.definitions.VmSizeCompatibilityFilter.properties.NodeTypes
       - $.definitions.VmSizeCompatibilityFilter.properties.ClusterFlavors
       - $.definitions.VmSizeCompatibilityFilter.properties.Regions
       - $.definitions.VmSizeCompatibilityFilter.properties.FilterMode
 ```

### Tag: package-2018-06-preview

These settings apply only when `--tag=package-2018-06-preview` is specified on the command line.

``` yaml $(tag) == 'package-2018-06-preview'
input-file:
- Microsoft.HDInsight/preview/2018-06-01-preview/cluster.json
- Microsoft.HDInsight/preview/2018-06-01-preview/applications.json
- Microsoft.HDInsight/preview/2018-06-01-preview/locations.json
- Microsoft.HDInsight/preview/2018-06-01-preview/configurations.json
- Microsoft.HDInsight/preview/2018-06-01-preview/extensions.json
- Microsoft.HDInsight/preview/2018-06-01-preview/scriptActions.json
- Microsoft.HDInsight/preview/2018-06-01-preview/operations.json
```


### Tag: package-2015-03-preview

These settings apply only when `--tag=package-2015-03-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-03-preview'
input-file:
- Microsoft.HDInsight/preview/2015-03-01-preview/cluster.json
- Microsoft.HDInsight/preview/2015-03-01-preview/applications.json
- Microsoft.HDInsight/preview/2015-03-01-preview/locations.json
- Microsoft.HDInsight/preview/2015-03-01-preview/configurations.json
- Microsoft.HDInsight/preview/2015-03-01-preview/extensions.json
- Microsoft.HDInsight/preview/2015-03-01-preview/scriptActions.json
- Microsoft.HDInsight/preview/2015-03-01-preview/operations.json
```


---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
```

## Python

See configuration in [readme.python.md](./readme.python.md)

## Go

See configuration in [readme.go.md](./readme.go.md)

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.HDInsight
  output-folder: $(csharp-sdks-folder)/HDInsight/Management.HDInsight/Generated
  clear-output-folder: true
```


## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.hdinsight
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-hdinsight
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2018-06-preview
  - tag: package-2015-03-preview
```


### Tag: package-2018-06-preview and java

These settings apply only when `--tag=package-2015-03-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-06-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.hdinsight.v2018_06_01_preview
  output-folder: $(azure-libraries-for-java-folder)/hdinsight/resource-manager/v2018_06_01_preview
regenerate-manager: true
generate-interface: true
```


### Tag: package-2015-03-preview and java

These settings apply only when `--tag=package-2015-03-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-03-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.hdinsight.v2015_03_01_preview
  output-folder: $(azure-libraries-for-java-folder)/hdinsight/resource-manager/v2015_03_01_preview
regenerate-manager: true
generate-interface: true
```


